@@ -4,7 +4,8 @@
 
 test_dir=$(cd $(dirname $0) && pwd)
 
-export WORKON_HOME="$(echo ${TMPDIR:-/tmp}/WORKON_HOME | sed 's|//|/|g')"
+tmplocation=${TMPDIR:-/tmp}
+export WORKON_HOME="$(echo ${tmplocation}/WORKON_HOME | sed 's|//|/|g')"
 
 export HOOK_VERBOSE_OPTION=-v
 
@@ -28,15 +29,15 @@ test_tempfile () {
     filename=$(virtualenvwrapper_tempfile hook)
     assertTrue "Filename is empty" "[ ! -z \"$filename\" ]"
     rm -f $filename
-    comparable_tmpdir=$(echo $TMPDIR | sed 's|/$||')
+    comparable_tmpdir=$(echo $tmplocation | sed 's|/$||')
     comparable_dirname=$(dirname $filename | sed 's|/$||')
-    assertSame "TMPDIR and path not the same for $filename" "$comparable_tmpdir" "$comparable_dirname"
+    assertSame "Temporary directory \"$tmplocation\" and path not the same for $filename" "$comparable_tmpdir" "$comparable_dirname"
     assertTrue "virtualenvwrapper-hook not in filename." "echo $filename | grep virtualenvwrapper-hook"
 }
 
 test_no_such_tmpdir () {
     old_tmpdir="$TMPDIR"
-    TMPDIR="$TMPDIR/does-not-exist"
+    export TMPDIR="$tmplocation/does-not-exist"
     virtualenvwrapper_run_hook "initialize" >/dev/null 2>&1
     RC=$?
     assertSame "Unexpected exit code $RC" "1" "$RC"
@@ -45,7 +46,7 @@ test_no_such_tmpdir () {
 
 test_tmpdir_not_writable () {
     old_tmpdir="$TMPDIR"
-    TMPDIR="$TMPDIR/cannot-write"
+    export TMPDIR="$tmplocation/cannot-write"
     mkdir "$TMPDIR"
     chmod ugo-w "$TMPDIR"
     virtualenvwrapper_run_hook "initialize" >/dev/null 2>&1
